@@ -81,6 +81,9 @@ namespace GLib {
 
 		static GType ()
 		{
+			if (!GLib.Thread.Supported)
+				GLib.Thread.Init ();
+
 			g_type_init ();
 
 			Register (GType.Char, typeof (sbyte));
@@ -93,7 +96,9 @@ namespace GLib {
 			Register (GType.Float, typeof (float));
 			Register (GType.Double, typeof (double));
 			Register (GType.String, typeof (string));
+			Register (GType.Pointer, typeof (IntPtr));
 			Register (GType.Object, typeof (GLib.Object));
+			Register (GType.Pointer, typeof (IntPtr));
 
 			// One-way mapping
 			gtypes[typeof (char)] = GType.UInt;
@@ -180,8 +185,8 @@ namespace GLib {
 					foreach (AssemblyName ref_name in asm.GetReferencedAssemblies ()) {
 						if (ref_name.Name != asm_name)
 							continue;
-						string asm_dir = Path.GetDirectoryName (asm.Location);
 						try {
+							string asm_dir = Path.GetDirectoryName (asm.Location);
 							Assembly ref_asm;
 							if (File.Exists (Path.Combine (asm_dir, ref_name.Name + ".dll")))
 								ref_asm = Assembly.LoadFrom (Path.Combine (asm_dir, ref_name.Name + ".dll"));
